/* $Id: guppi-text-squeeze.h,v 1.8 2001/11/19 05:40:52 trow Exp $ */

/*
 * guppi-text-squeeze.h
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GUPPI_TEXT_SQUEEZE_H
#define _INC_GUPPI_TEXT_SQUEEZE_H

#include <glib.h>
#include  "guppi-defs.h"

BEGIN_GUPPI_DECLS

/* I got the idea for this from a demo Graham Wills showed me... */
  gchar * guppi_text_squeeze (const gchar * txt, gint length);


END_GUPPI_DECLS

#endif /* _INC_GUPPI_TEXT-SQUEEZE_H */

/* $Id: guppi-text-squeeze.h,v 1.8 2001/11/19 05:40:52 trow Exp $ */
